@@ -30,9 +30,11 @@ def send_ssh_key(saml_client: "SAMLClient", instance: str, ssh_key: "SymConfigFi
     command = dedent(
         f"""
         #!/bin/bash
+        mkdir -p "$(echo ~{user})/.ssh"
         echo "{ssh_key.path.with_suffix('.pub').read_text()}" >> "$(echo ~{user})/.ssh/authorized_keys"
+        chown -R {user}:{user} "$(echo ~{user})/.ssh"
         """
-    )
+    ).strip()
     # fmt: on
     ssm_client.send_command(
         InstanceIds=[instance],
@@ -43,7 +45,6 @@ def send_ssh_key(saml_client: "SAMLClient", instance: str, ssh_key: "SymConfigFi
 
 
 def find_instance(saml_client, keys, value) -> Optional[str]:
-    creds = saml_client.get_creds()
     ec2_client = boto_client(saml_client, "ec2")
     for key in keys:
         response = ec2_client.describe_instances(
