@@ -17,7 +17,7 @@ SSHKey = SymConfigFile("ssh/key")
 
 @run_subprocess
 def gen_ssh_key(dest: SymConfigFile):
-    dest.parent.mkdir(parents=True, exist_ok=True)
+    dest.path.parent.mkdir(parents=True, exist_ok=True)
     dest.path.unlink(missing_ok=True)
     yield "ssh-keygen", {"t": "rsa", "f": str(dest), "N": ""}
 
