@@ -3,10 +3,13 @@ from pathlib import Path
 from typing import Callable, ContextManager, Iterator
 from uuid import UUID, uuid4
 
+import click
 import pytest
 from _pytest.monkeypatch import MonkeyPatch
 
+from sym.cli.commands import GlobalOptions
 from sym.cli.helpers.config import Config
+from sym.cli.sym import sym as click_command
 from sym.cli.tests.helpers.capture import CaptureCommand
 from sym.cli.tests.helpers.sandbox import Sandbox
 
@@ -34,7 +37,7 @@ def custom_org(monkeypatch: MonkeyPatch) -> CustomOrgFixture:
     @contextmanager
     def custom_org(org: str) -> Iterator[None]:
         with monkeypatch.context() as mp:
-            mp.setattr(Config, "get_org", lambda self: org)
+            mp.setattr(Config, "get_org", classmethod(lambda cls: org))
             yield
 
     return custom_org
@@ -43,3 +46,10 @@ def custom_org(monkeypatch: MonkeyPatch) -> CustomOrgFixture:
 @pytest.fixture
 def capture_command(monkeypatch: MonkeyPatch) -> CaptureCommand:
     return CaptureCommand(monkeypatch)
+
+
+@pytest.fixture
+def click_context():
+    with click.Context(click_command) as ctx:
+        ctx.ensure_object(GlobalOptions)
+        yield ctx
